@@ -5,7 +5,7 @@
 #   Authors:          Shuo Liu, Gil Keren, Bjoern Schuller                                                             #
 #   Affiliation:      Chair of Embedded Intelligence for Health Care and Wellbeing, University of Augsburg (UAU)       #
 #   Version:          2.0                                                                                              #
-#   Last Update:      May. 06, 2020                                                                                    #
+#   Last Update:      June. 17, 2020                                                                                    #
 #   Dependence Files: xxx                                                                                              #
 #   Contact:          shuo.liu@informatik.uni-augburg.de                                                               #
 ########################################################################################################################
@@ -406,8 +406,8 @@ def apply_demo(speechpath, pospath, negpath, save_to):
     mix_centers = np.concatenate(mix_centers, axis=0)
 
     recover_samples_from_spectrum(denoised, mixedphs_[:, 0, :], save_to)
-    mix_save_to = save_to[:-15] + 'mixed_demo.wav'
-    recover_samples_from_spectrum(mix_centers, mixedphs_[:, 0, :], mix_save_to)
+    #mix_save_to = save_to[:-15] + 'mixed_demo.wav'
+    #recover_samples_from_spectrum(mix_centers, mixedphs_[:, 0, :], mix_save_to)
 
 
 def apply_snc(mixedpath, pospath, negpath, save_to):
@@ -530,10 +530,9 @@ def apply_snc(mixedpath, pospath, negpath, save_to):
     mixed_samples = recover_samples_from_spectrum(mix_centers, mixedphs_[:, 0, :], mix_save_to)
     removed_save_to = save_to_temp[:-12] + 'removed.wav'
     removed_samples = mixed_samples - denoised_samples
-    wavwrite(removed_save_to, 16000, removed_samples)
+    #wavwrite(removed_save_to, 16000, removed_samples)
 
     snr_est = np.mean(np.square(denoised_samples)) / np.mean(np.square(removed_samples))
-    print(snr_est)
     print('---------------------------')
     if not FLAGS.ac:
         compensation_factor = FLAGS.compensate
@@ -541,7 +540,7 @@ def apply_snc(mixedpath, pospath, negpath, save_to):
         compensation_factor = snr_est / 20
     compensated_save_to = save_to_temp[:-12] + 'compensated.wav'
     compensated_samples = denoised_samples + removed_samples * compensation_factor
-    wavwrite(compensated_save_to, 16000, compensated_samples)
+    # wavwrite(compensated_save_to, 16000, compensated_samples)
 
     # snr = S/N   snr_est = S-e / N+e
     # e is distortion, need to be compensate. For a definite snr, Lower snr_est requires more compensation.
