@@ -236,7 +236,7 @@ def recover_samples_from_spectrum(logspectrum_stft, spectrum_phase, save_to):
     istft_graph = tf.Graph()
     with istft_graph.as_default():
         stft_ph = tf.placeholder(tf.complex64, shape=(None, 201))
-        samples = tf.contrib.signal.inverse_stft(stft_ph, 400, 160, 400, window_fn=tf.signal.inverse_stft_window_fn(160, forward_window_fn=functools.partial(tf.signal.hann_window, periodic=True)))
+        samples = tf.signal.inverse_stft(stft_ph, 400, 160, 400, window_fn=tf.signal.inverse_stft_window_fn(160, forward_window_fn=functools.partial(tf.signal.hann_window, periodic=True)))
         istft_sess = tf.Session(config=tf.ConfigProto(allow_soft_placement=True))
         samples_ = istft_sess.run(samples, feed_dict={stft_ph: spectrum})
         wavwrite(save_to, 16000, samples_)
@@ -271,7 +271,7 @@ def apply_demo(cleanpath, noisepath, save_to):
 
             sess = tf.Session(config=tf.ConfigProto(allow_soft_placement=True))
 
-            mix_stft, clean_stft, noise_stft = [tf.contrib.signal.stft(wav, 400, 160, fft_length=400) for wav in [mix_wav, clean_wav, noise_wav]]
+            mix_stft, clean_stft, noise_stft = [tf.signal.stft(wav, 400, 160, fft_length=400) for wav in [mix_wav, clean_wav, noise_wav]]
 
             mix_spectrum, clean_spectrum, noise_spectrum = [tf.log(tf.abs(wav_stft) + 1e-5) for wav_stft in [mix_stft, clean_stft, noise_stft]]
 
@@ -381,7 +381,7 @@ def apply_separator(mixedpath, cleanpath, noisepath, save_to):
 
             sess = tf.Session(config=tf.ConfigProto(allow_soft_placement=True))
 
-            mix_stft, clean_stft, noise_stft = [tf.contrib.signal.stft(wav, 400, 160, fft_length=400) for wav in [mix_wav, clean_wav, noise_wav]]
+            mix_stft, clean_stft, noise_stft = [tf.signal.stft(wav, 400, 160, fft_length=400) for wav in [mix_wav, clean_wav, noise_wav]]
 
             mix_spectrum, clean_spectrum, noise_spectrum = [tf.log(tf.abs(wav_stft) + 1e-5) for wav_stft in [mix_stft, clean_stft, noise_stft]]
 
