@@ -3,9 +3,9 @@
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ #
 #   Description:      Data reader pipeline.                                                                            #
 #   Authors:          Shuo Liu, Gil Keren, Bjoern Schuller                                                             #
-#   Affiliation:      Chair of Embedded Intelligence for Health Care and Wellbeing, University of Augsburg (UAU)  #
+#   Affiliation:      Chair of Embedded Intelligence for Health Care and Wellbeing, University of Augsburg (UAU)       #
 #   Version:          2.0                                                                                              #
-#   Last Update:      May. 06, 2020                                                                                    #
+#   Last Update:      June. 17, 2020                                                                                   #
 #   Dependence Files: xxx                                                                                              #
 #   Contact:          shuo.liu@informatik.uni-augburg.de                                                               #
 ########################################################################################################################
@@ -269,10 +269,10 @@ class read_seeds:
         target_wav, noise_wav, mix_wav = [tf.reshape(x, [-1]) for x in (target_wav, noise_wav, mix_wav)]
 
         # stft
-        target_fft = tf.contrib.signal.stft(target_wav, self.frame_length, self.frame_step,
+        target_fft = tf.signal.stft(target_wav, self.frame_length, self.frame_step,
                                             fft_length=self.frame_length)
-        noise_fft = tf.contrib.signal.stft(noise_wav, self.frame_length, self.frame_step, fft_length=self.frame_length)
-        mix_fft = tf.contrib.signal.stft(mix_wav, self.frame_length, self.frame_step, fft_length=self.frame_length)
+        noise_fft = tf.signal.stft(noise_wav, self.frame_length, self.frame_step, fft_length=self.frame_length)
+        mix_fft = tf.signal.stft(mix_wav, self.frame_length, self.frame_step, fft_length=self.frame_length)
 
         # Magnitude
         target_mag, noise_mag, mix_mag = [tf.abs(x) for x in [target_fft, noise_fft, mix_fft]]
